/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLCollection.h"
#include "Node.h"
#include "SQLError.h"
#include "StyleSheet.h"
#include "Text.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomDOMObject.h"
#include "gdom/GdomSQLError.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateGdomSQLError.h"
#include "gdom/PrivateIntGdomSQLError.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
gpointer toGDOM(WebCore::SQLError* obj)
{
    return WebCore::cacheDOMObject<WebCore::SQLError, GDOMSQLError>(obj);
}
} /* namespace WebCore */
extern "C" {

GDOMSQLError::GDOMSQLError(PassRefPtr<WebCore::SQLError> impl)
    : GDOMObject()
    , m_impl(impl)
{
}

GDOMSQLError::~GDOMSQLError()
{
    m_impl.get()->deref();
    WebCore::GDOMScriptInterpreter::forgetDOMObject(m_impl.get());

}

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "SQLError.h"
#include <gdom/GdomSQLError.h>
#include <gdom/PrivateGdomSQLError.h>
#include <gdom/PrivateIntGdomSQLError.h>
#include <gdom/GdomSQLErrorprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomSQLError, gdom_sql_error, GDOM_TYPE_DOM_OBJECT);

/*
struct _GdomSQLErrorPrivate {
    class WebCore::SQLError *item;
};

#define GDOM_SQL_ERROR_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_SQL_ERROR, GdomSQLErrorPrivate))
*/
G_END_DECLS
WebCore::SQLError *
gdom_sql_error_get_private(GdomSQLError *request)
{
    GDOMSQLError *res;
    res = static_cast<GDOMSQLError*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::SQLError*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
    PROP_CODE,
    PROP_MESSAGE,
};


static void gdom_sql_error_finalize(GObject* object)
{
    /*GdomSQLError* request = GDOM_SQL_ERROR(object);*/
    /*GdomSQLErrorPrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_DOM_OBJECT));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_sql_error_parent_class)->finalize(object);
}

static void gdom_sql_error__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomSQLError *self = GDOM_SQL_ERROR(object);
    WebCore::SQLError * gself = (gdom_sql_error_get_private(self));
    switch (prop_id) {
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_sql_error__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomSQLError *self = GDOM_SQL_ERROR(object);
    WebCore::SQLError * gself = (gdom_sql_error_get_private(self));
    switch (prop_id) {
    case PROP_CODE:
    {
         g_value_set_uint (value, gself->code());
         break;
    }
    case PROP_MESSAGE:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->message()));
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_sql_error_class_init(GdomSQLErrorClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_sql_error_finalize;
    g_klass->set_property = gdom_sql_error__set_property_fn;
    g_klass->get_property = gdom_sql_error__get_property_fn;

    g_object_class_install_property (g_klass, PROP_CODE,
            g_param_spec_uint ("code", /* name */
                "sql_error_code", /* short description */
                "read-only  guint SQLError.code", /* longer - could do with some extra doc stuff here */
                 0,        /* min */
                G_MAXUINT, /* max */
                0,        /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_MESSAGE,
            g_param_spec_string ("message", /* name */
                "sql_error_message", /* short description */
                "read-only  gchar * SQLError.message", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));





    /*g_type_class_remove_private(requestClass, sizeof(GdomSQLErrorPrivate));*/
}

static void gdom_sql_error_init(GdomSQLError* request)
{
    /*GdomSQLErrorPrivate* priv = GDOM_SQL_ERROR_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

